@@ -7,14 +7,15 @@
 
 
 srvf_to_curve <- function(t, srv_curve) {
+  ndim <- length(srv_curve(0))
   integrand <- function(t) sweep( srv_curve(t), 2, sqrt(colSums(srv_curve(t)^2)), "*" )
-  integrand_1 <- function(t) integrand(t)[1,]
-  integrand_2 <- function(t) integrand(t)[2,]
-  piece_integrate <- function(i, f) integrate(f = f, lower = t[i], upper = t[i+1],
-                                              stop.on.error = FALSE)$value
-  piece_integrals <- rbind( sapply(1:(length(t)-1), piece_integrate, f = integrand_1),
-                            sapply(1:(length(t)-1), piece_integrate, f = integrand_2))
-  piece_integrals <- cbind(c(0,0), piece_integrals)
+  piece_integrals <- lapply(1:ndim, function(j){
+    integrand_j <- function(t) integrand(t)[j,]
+    piece_integrate <- function(i, f) integrate(f = f, lower = t[i], upper = t[i+1],
+                                                stop.on.error = FALSE)$value
+    piece_integral <- c(0, sapply(1:(length(t)-1), piece_integrate, f = integrand_j))
+  })
+  piece_integrals <- do.call("rbind", piece_integrals)
   t(apply(piece_integrals, 1, cumsum))
 }
 
@@ -28,7 +29,7 @@ srvf_to_curve <- function(t, srv_curve) {
 center_curve <- function(data_curve){
   coord_idx <- !(colnames(data_curve) %in% c("t", "id"))
   data_curve[,coord_idx] <- data_curve[,coord_idx] -
-    matrix(colMeans(data_curve[,coord_idx]), nrow = nrow(data_curve),
-           ncol = ncol(data_curve[,coord_idx]), byrow = TRUE)
+    matrix(colMeans(data_curve[,coord_idx, drop = FALSE]), nrow = nrow(data_curve),
+           ncol = ncol(data_curve[,coord_idx, drop = FALSE]), byrow = TRUE)
   data_curve
 }
